@@ -1,7 +1,7 @@
 package Data::Sah::CoerceCommon;
 
-our $DATE = '2016-05-23'; # DATE
-our $VERSION = '0.011'; # VERSION
+our $DATE = '2016-05-24'; # DATE
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -245,7 +245,8 @@ sub get_coerce_rules {
         while ($i < @rules) {
             my $rule = $rules[$i];
             if ($rule->{meta}{precludes}) {
-                for my $j (reverse($i+1 .. $#rules)) {
+                for my $j (reverse 0 .. $#rules) {
+                    next if $j == $i;
                     my $match;
                     for my $p (@{ $rule->{meta}{precludes} }) {
                         if (ref($p) eq 'Regexp' && $rules[$j]{name} =~ $p ||
@@ -282,7 +283,7 @@ Data::Sah::CoerceCommon - Common stuffs for Data::Sah::Coerce and Data::Sah::Coe
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2016-05-23.
+This document describes version 0.012 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2016-05-24.
 
 =head1 FUNCTIONS
 
